Module client

Module client 

Structs

RequestFuture
This future represents a RPC request that is currently being executed. Note that dropping this future will result in the RPC request being cancelled
StreamReceiver
A stream of items from a streaming RPC method. Dropping this will send an abort to the server, cancelling the stream. Call close to stop the server while still draining buffered items.