pub trait JsName {
const NAME: &'static str;
}Expand description
The DOM class name of a Javascript type, for the generated Typescript declarations.
Implemented for the js_sys types listed below and for the web_sys transferable objects.
A Javascript type outside that list needs a local newtype implementing this trait, since
the orphan rule prevents implementing it downstream for a foreign type.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".